@@ -43,7 +43,7 @@
 extern "C" 
 {
 #endif
-SLANG_MODULE(gslinterp);
+/* SLANG_MODULE(gslinterp); */
 #ifdef __cplusplus
 }
 #endif
@@ -326,17 +326,17 @@ static void do_interp (double (*fun)(const gsl_interp *, const double [], const
 
 
 #define INTERP_FUN(fun,type,name) \
-   static void name (void) \
+  static void name (void) \
+  { \
+     if (SLang_Num_Function_Args != 3) \
        { \
-	  if (SLang_Num_Function_Args != 3) \
-	    { \
-	       SLang_verror (SL_USAGE_ERROR, "Usage: y=%s(double x, double xa[], double ya[])", #name); \
-	       return; \
-	    } \
-	  slgsl_reset_errors (); \
-	  do_interp (fun, type); \
-	  slgsl_check_errors (#name); \
-       }
+	  SLang_verror (SL_USAGE_ERROR, "Usage: y=%s(double x, double xa[], double ya[])", #name); \
+	  return; \
+       } \
+     slgsl_reset_errors (); \
+     do_interp (fun, type); \
+     slgsl_check_errors (#name); \
+  }
 
 INTERP_FUN(gsl_interp_eval, gsl_interp_linear, interp_linear)
 INTERP_FUN(gsl_interp_eval_deriv, gsl_interp_linear, interp_linear_deriv)
@@ -443,17 +443,17 @@ static void do_interp_integ (const gsl_interp_type *type)
 }
 
 #define INTEG_FUN(type,name) \
-   static void name (void) \
+  static void name (void) \
+  { \
+     if (SLang_Num_Function_Args != 4) \
        { \
-	  if (SLang_Num_Function_Args != 4) \
-	    { \
-	       SLang_verror (SL_USAGE_ERROR, "Usage: y=%s(double xa[], double ya[], double a, double b)", #name); \
-	       return; \
-	    } \
-	  slgsl_reset_errors (); \
-	  do_interp_integ (type); \
-	  slgsl_check_errors (#name); \
-       }
+	  SLang_verror (SL_USAGE_ERROR, "Usage: y=%s(double xa[], double ya[], double a, double b)", #name); \
+	  return; \
+       } \
+     slgsl_reset_errors (); \
+     do_interp_integ (type); \
+     slgsl_check_errors (#name); \
+  }
 
 INTEG_FUN(gsl_interp_linear,interp_linear_integ)
 INTEG_FUN(gsl_interp_polynomial,interp_polynomial_integ)
@@ -463,17 +463,17 @@ INTEG_FUN(gsl_interp_akima,interp_akima_integ)
 INTEG_FUN(gsl_interp_akima_periodic,interp_akima_periodic_integ)
 
 #define INTERP_INIT_FUN(type,name) \
-   static void name (void) \
+  static void name (void) \
+  { \
+     if (SLang_Num_Function_Args != 2) \
        { \
-	  if (SLang_Num_Function_Args != 2) \
-	    { \
-	       SLang_verror (SL_USAGE_ERROR, "Usage: y=%s(double xa[], double ya[])", #name); \
-	       return; \
-	    } \
-	  slgsl_reset_errors (); \
-	  do_interp_init (type); \
-	  slgsl_check_errors (#name); \
-       }
+	  SLang_verror (SL_USAGE_ERROR, "Usage: y=%s(double xa[], double ya[])", #name); \
+	  return; \
+       } \
+     slgsl_reset_errors (); \
+     do_interp_init (type); \
+     slgsl_check_errors (#name); \
+  }
 INTERP_INIT_FUN(gsl_interp_linear, interp_linear_init)
 INTERP_INIT_FUN(gsl_interp_polynomial,interp_polynomial_init)
 INTERP_INIT_FUN(gsl_interp_cspline,interp_cspline_init)
@@ -482,17 +482,17 @@ INTERP_INIT_FUN(gsl_interp_akima,interp_akima_init)
 INTERP_INIT_FUN(gsl_interp_akima_periodic,interp_akima_periodic_init)
 
 #define INTERP_EVAL_FUN(fun,name) \
-   static void name (void) \
+  static void name (void) \
+  { \
+     if (SLang_Num_Function_Args != 2) \
        { \
-	  if (SLang_Num_Function_Args != 2) \
-	    { \
-	       SLang_verror (SL_USAGE_ERROR, "Usage: y=%s(GSL_Interp_Type c, double x)", #name); \
-	       return; \
-	    } \
-	  slgsl_reset_errors (); \
-	  do_interp_eval (fun); \
-	  slgsl_check_errors (#name); \
-       }
+	  SLang_verror (SL_USAGE_ERROR, "Usage: y=%s(GSL_Interp_Type c, double x)", #name); \
+	  return; \
+       } \
+     slgsl_reset_errors (); \
+     do_interp_eval (fun); \
+     slgsl_check_errors (#name); \
+  }
 
 INTERP_EVAL_FUN(gsl_interp_eval, interp_eval)
 INTERP_EVAL_FUN(gsl_interp_eval_deriv, interp_eval_deriv)
