@@ -43,7 +43,7 @@
 extern "C" 
 {
 #endif
-SLANG_MODULE(gslrand);
+/* SLANG_MODULE(gslrand); */
 #ifdef __cplusplus
 }
 #endif
@@ -250,36 +250,47 @@ static Rand_Type *pop_rand_nds_and_int (int nargs, int nds, SLang_MMT_Type **mmt
 	return get_default_generator ();
      }
    
-   /* nargs = nds + 1 */
+   /* nargs = nds + 1 :
+    * There are two possibilities: 
+    *   case 1: rng d1 d2 ... dn
+    *   case 2: d1 d2 ... dn i
+    */
    if (-1 == SLroll_stack (-nargs))
      return NULL;
 
    r = NULL; mmt = NULL;
    if (Rand_Type_Id == SLang_peek_at_stack ())
      {
+	/* case 1 */
 	if (NULL == (r = pop_rand_type (&mmt)))
 	  return NULL;
 	*mmtp = mmt;
+
+	if (-1 == pop_n_doubles (nds, ds))
+	  {
+	     SLang_free_mmt (mmt);
+	     *mmtp = NULL;
+	     return NULL;
+	  }
+	return r;
      }
 
-   if (-1 == pop_n_doubles (nds, ds))
-     {
-	if (mmt != NULL)
-	  SLang_free_mmt (mmt);
-	*mmtp = NULL;
-	return NULL;
-     }
+   /* case 2 */
+   *mmtp = NULL;
 
-   if (r != NULL)
-     return r;
-   
-   if (NULL == (r = get_default_generator ()))
+   if (-1 == SLroll_stack (nargs))
      return NULL;
-   
+
    if (-1 == SLang_pop_integer (ip))
      return NULL;
    
-   return r;
+   if (-1 == pop_n_doubles (nds, ds))
+     {
+	SLang_free_mmt (mmt);
+	return NULL;
+     }
+   
+   return get_default_generator ();
 }
 
 static void rng_alloc (void)
@@ -783,6 +794,64 @@ PDF_D_FDD(gsl_ran_laplace_pdf, "laplace_pdf")
 PDF_D_FDDD(gsl_ran_weibull_pdf, "weibull_pdf")
 /* discrete_pdf */
 
+						
+/* static void bivariate_gaussian_pdf (){} */
+static void ran_bivariate_gaussian (void)
+{
+   SLang_MMT_Type *mmt;
+   Rand_Type *r;
+   double ds[3];
+   SLang_Array_Type *at_x = NULL, *at_y = NULL;
+   double *xp, *yp;
+   SLindex_Type i, num;
+   double sx, sy, rho;
+   const gsl_rng *rng;
+   char *fun = "ran_bivariate_gaussian";
+
+   if ((SLang_Num_Function_Args < 3) || (SLang_Num_Function_Args > 5))
+     {
+	SLang_verror (SL_USAGE_ERROR, "Usage: (x,y)=%s([GSL_Rng_Type,] sx, sy, rho, [,num])", fun);
+	return;
+     }
+   if (NULL == (r = pop_rand_nds_and_int (SLang_Num_Function_Args, 3, &mmt, ds, &num)))
+     return;
+
+   sx = ds[0]; sy = ds[1]; rho = ds[2];
+   rng = r->gen;
+
+   if (num < 0)
+     {
+	double x, y;
+	slgsl_reset_errors ();
+	gsl_ran_bivariate_gaussian (rng, sx, sy, rho, &x, &y);
+	slgsl_check_errors (fun);
+	(void) SLang_push_double (x);
+	(void) SLang_push_double (y);
+	goto free_return;
+     }
+   
+   if ((NULL == (at_x = SLang_create_array (SLANG_DOUBLE_TYPE, 0, NULL, &num, 1)))
+       || (NULL == (at_y = SLang_create_array (SLANG_DOUBLE_TYPE, 0, NULL, &num, 1))))
+     goto free_return;
+
+   xp = (double *) at_x->data;
+   yp = (double *) at_y->data;
+
+   slgsl_reset_errors ();
+   for (i = 0; i < num; i++)
+     gsl_ran_bivariate_gaussian (rng, sx, sy, rho, xp+i, yp+i);
+   slgsl_check_errors (fun);
+
+   (void) SLang_push_array (at_x, 0);
+   (void) SLang_push_array (at_y, 0);
+   /* drop */
+
+   free_return:
+   if (mmt != NULL) SLang_free_mmt (mmt);
+   if (at_x != NULL) SLang_free_array (at_x);
+   if (at_y != NULL) SLang_free_array (at_y);
+}
+
 #define V SLANG_VOID_TYPE
 static SLang_Intrin_Fun_Type Module_Intrinsics [] =
 {
@@ -801,6 +870,7 @@ static SLang_Intrin_Fun_Type Module_Intrinsics [] =
    MAKE_INTRINSIC_0("ran_bernoulli", SLF(gsl_ran_bernoulli), V),
    MAKE_INTRINSIC_0("ran_beta", SLF(gsl_ran_beta), V),
    /* MAKE_INTRINSIC_0("ran_binomial", SLF(u_dd_gsl_ran_binomial), V), */
+   MAKE_INTRINSIC_0("ran_bivariate_gaussian", ran_bivariate_gaussian, V),
    MAKE_INTRINSIC_0("ran_cauchy", SLF(gsl_ran_cauchy), V),
    MAKE_INTRINSIC_0("ran_chisq", SLF(gsl_ran_chisq), V),
    MAKE_INTRINSIC_0("ran_erlang", SLF(gsl_ran_erlang), V),
